//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// Program        : ModularCounter Driver
//
// Author         : Richard E. Pattis
//                  Computer Science Department
//                  Carnegie Mellon University
//                  5000 Forbes Avenue
//                  Pittsburgh, PA 15213-3891
//                  e-mail: pattis@cs.cmu.edu
//
// Maintainer     : Author
//
//
// Description:
//
//   This program implements a driver for the ModularCounter class. Most
// of its menu selections allow the user to call the individual methods
// declared in this class (all accessors) on an object that it
// constructs. Other menu items perform combinations of these methods.
// In this way, programmers can learn about this class by experimenting
// with its methods.
//
// Known Bugs     : None
//
// Future Plans   : None
//
// Program History:
//   9/11/01: R. Pattis - Operational in Java
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////


import edu.cmu.cs.pattis.cs151xx.Prompt;
import edu.cmu.cs.pattis.cs151xx.ModularCounter;



public class Application {


  //Present menu and get user's choice
  
  private static char menuPrompt (ModularCounter mc)
  {
    System.out.println("\nReference counter = " + mc);  //uses toString method
    
    System.out.println("Accessors               Mutator          General");
    System.out.println("  v - getValue            r - reset        q - quit");
    System.out.println("  m - getModulus          i - inc");
    System.out.println("  ? - many comparisons    I - int(delta)");
    System.out.println("                          d - dec");
    System.out.println("                          D - dec(delta)");
    System.out.println("                          u - update(delta)");
    System.out.println("                          n - new");
    
    return Prompt.forChar("\nEnter Command","vm?riIdDunq");
  }
  
  
  
  ////////////////
  //Driver Program
  ////////////////
  
 
	public static void main(String[] args)
	{
	  //Prompt for construction arguments; get object to test; Don't use constructor directly
	  ModularCounter mc = ModularCounter.prompt("Constructing reference counter"); 
	  
	  for (;;)
	    try {
  	    char selection = menuPrompt(mc);
  	    
        if (selection == 'v')
          System.out.println("  value = " + mc.getValue());
          
        else if (selection == 'm')
          System.out.println("  modulus = " + mc.getModulus());
       
        else if (selection == '?') {
  	       int v = Prompt.forInt("Enter comparison value  ");
  	       int m = Prompt.forInt("Enter comparison modulus");
      	   ModularCounter m2 = new ModularCounter(v,m);
           System.out.println("mc.equals(m2)    = " + mc.equals(m2));
           System.out.println("mc.compareTo(m2) = " + mc.compareTo(m2));
           System.out.println("mc.isZero()      = " + mc.isZero());
        }
          
        else if (selection == 'r')
          mc.reset();

        else if (selection == 'i')
          mc.inc();

        else if (selection == 'I')
          mc.inc(Prompt.forInt("  Enter delta to increment by"));

        else if (selection == 'd')
          mc.dec();
          
        else if (selection == 'D')
          mc.dec(Prompt.forInt("  Enter delta to decrement by"));

        else if (selection == 'u')
          mc.update(Prompt.forInt("  Enter delta to increment/decrement by"));

        else if (selection == 'n')
  	      mc = ModularCounter.prompt("Enter new ModularCounter");     //Don't use constructor directly
  	    
        else if (selection == 'q')
          break;
        
        else
          System.out.println("\""+selection+"\" is unknown command");

      }catch(Exception e) {
        System.out.println("  Exception Caught/Handled: "+e.getMessage());
      }
  }
}
